==> core-1.0.0.tgz: package/lib/class-names/chip-list-class-names.js <==
import { getHostClassNames } from './class-names';
import { validateUiComponentProps } from '../ui-component-props/ui-component-props';
export const chipListLayoutClassNamesConfig = {
    prefix: 'cck-chip-list',
    elements: {
        host: {
            name: 'Host Element',
            selectors: [
                'cck-chip-list'
            ],
            description: 'It will add to the host element of ChipList component.'
        },
        disabled: {
            name: 'Host Element',
            selectors: [
                'cck-chip-list--disabled'
            ],
            description: 'Applied to the host element of the ChipList component, when the the ChipList is disabled'
        },
        input: {
            name: 'Host Element',
            selectors: [
                'cck-chip-list__input'
            ],
            description: 'Applied to the input element of the ChipList component, to write and add new chip'
        }
    }
};
export function getChipListClassNames(componentProps, uiComponentsConfig) {
    const options = {
        componentName: 'chip',
        componentProps,
        uiComponentsConfig
    };
    validateUiComponentProps(options);
    return {
        host: [
            ...chipListLayoutClassNamesConfig.elements.host.selectors,
            ...getHostClassNames(chipListLayoutClassNamesConfig.prefix, options)
        ],
        disabled: [
            ...chipListLayoutClassNamesConfig.elements.disabled.selectors
        ],
        input: [
            ...chipListLayoutClassNamesConfig.elements.input.selectors
        ]
    };
}

==> core-1.1.0.tgz: package/lib/class-names/chip-list-class-names.js <==
import { getHostClassNames } from './class-names';
import { validateUiBaseComponentProps } from '../ui-component-props/ui-component-props';
export const chipListLayoutClassNamesConfig = {
    prefix: 'cck-chip-list',
    elements: {
        host: {
            name: 'Host Element',
            selectors: [
                'cck-chip-list'
            ],
            description: 'It will add to the host element of ChipList component.'
        },
        disabled: {
            name: 'Host Element',
            selectors: [
                'cck-chip-list--disabled'
            ],
            description: 'Applied to the host element of the ChipList component, when the the ChipList is disabled'
        },
        input: {
            name: 'Host Element',
            selectors: [
                'cck-chip-list__input'
            ],
            description: 'Applied to the input element of the ChipList component, to write and add new chip'
        }
    }
};
export function getChipListClassNames(componentProps, themeConfig) {
    const options = {
        componentName: 'chip',
        componentProps,
        themeConfig
    };
    validateUiBaseComponentProps(options);
    return {
        host: [
            ...chipListLayoutClassNamesConfig.elements.host.selectors,
            ...getHostClassNames(chipListLayoutClassNamesConfig.prefix, options)
        ].join(' '),
        disabled: [
            ...chipListLayoutClassNamesConfig.elements.disabled.selectors
        ].join(' '),
        input: [
            ...chipListLayoutClassNamesConfig.elements.input.selectors
        ].join(' ')
    };
}
